@@ -23,7 +23,7 @@ from errors  import ResponseError, NoSuchObject, \
 
 from socket  import timeout
 import consts
-from utils   import requires_name
+from utils   import unicode_quote, requires_name
 
 # Because HTTPResponse objects *have* to have read() called on them
 # before they can be used again ...
@@ -345,6 +345,62 @@ class Object(object):
                 if hdr[0].lower() == 'etag':
                     self._etag = hdr[1]
 
+    @requires_name(InvalidObjectName)
+    def copy_to(self, container_name, name):
+        """
+        Copy an object's contents to another location.
+        """
+
+        self._name_check()
+        self._name_check(name)
+
+        # This method implicitly disables verification.
+        if not self._etag_override:
+            self._etag = None
+
+        headers = self._make_headers()
+        headers['Destination'] = "%s/%s" % (container_name, name)
+        headers['Content-Length'] = 0
+        response = self.container.conn.make_request(
+                   'COPY', [self.container.name, self.name], hdrs=headers, data='')
+        buff = response.read()
+
+        if response.status < 200 or response.status > 299:
+            raise ResponseError(response.status, response.reason)
+
+        # Reset the etag to what the server returns.
+        for hdr in response.getheaders():
+            if hdr[0].lower() == 'etag':
+                self._etag = hdr[1]
+
+    @requires_name(InvalidObjectName)
+    def copy_from(self, container_name, name):
+        """
+        Copy another object's contents to this object.
+        """
+
+        self._name_check()
+        self._name_check(name)
+
+        # This method implicitly disables verification.
+        if not self._etag_override:
+            self._etag = None
+
+        headers = self._make_headers()
+        headers['X-Copy-From'] = "%s/%s" % (container_name, name)
+        headers['Content-Length'] = 0
+        response = self.container.conn.make_request(
+                   'PUT', [self.container.name, self.name], hdrs=headers, data='')
+        buff = response.read()
+
+        if response.status < 200 or response.status > 299:
+            raise ResponseError(response.status, response.reason)
+
+        # Reset the etag to what the server returns.
+        for hdr in response.getheaders():
+            if hdr[0].lower() == 'etag':
+                self._etag = hdr[1]
+
     @requires_name(InvalidObjectName)
     def send(self, iterable):
         """
@@ -387,7 +443,7 @@ class Object(object):
                 raise StopIteration()
             iterable = file_iterator(iterable)
 
-        # This method implicitly diables verification
+        # This method implicitly disables verification.
         if not self._etag_override:
             self._etag = None
 
@@ -395,7 +451,7 @@ class Object(object):
             self.content_type = 'application/octet-stream'
 
         path = "/%s/%s/%s" % (self.container.conn.uri.rstrip('/'), \
-                quote(self.container.name), quote(self.name))
+                unicode_quote(self.container.name), unicode_quote(self.name))
         headers = self._make_headers()
         if self.size is None:
             del headers['Content-Length']
@@ -489,9 +545,11 @@ class Object(object):
     def __str__(self):
         return self.name
 
-    def _name_check(self):
-        if len(self.name) > consts.object_name_limit:
-            raise InvalidObjectName(self.name)
+    def _name_check(self, name=None):
+        if name is None:
+            name = self.name
+        if len(name) > consts.object_name_limit:
+            raise InvalidObjectName(name)
 
     def _make_headers(self):
         """
@@ -509,7 +567,6 @@ class Object(object):
             headers['Content-Type'] = self.content_type
         else:
             headers['Content-Type'] = 'application/octet-stream'
-
         for key in self.metadata:
             if len(key) > consts.meta_name_limit:
                 raise(InvalidMetaName(key))
@@ -546,6 +603,55 @@ class Object(object):
         """
         return "%s/%s" % (self.container.public_uri().rstrip('/'),
                 quote(self.name))
+    
+    def public_ssl_uri(self):
+        """
+        Retrieve the SSL URI for this object, if its container is public.
+
+        >>> container1 = connection['container1']
+        >>> container1.make_public()
+        >>> container1.create_object('file.txt').write('testing')
+        >>> container1['file.txt'].public_ssl_uri()
+        'https://c61.ssl.cf0.rackcdn.com/file.txt'
+
+        @return: the public SSL URI for this object
+        @rtype: str
+        """
+        return "%s/%s" % (self.container.public_ssl_uri().rstrip('/'),
+                quote(self.name))
+
+    def purge_from_cdn(self, email=None):
+        """
+        Purge Edge cache for this object.
+        You will be notified by email if one is provided when the
+        job completes.
+
+        >>> obj.purge_from_cdn("user@dmain.com")
+
+        or
+
+        >>> obj.purge_from_cdn("user@domain.com,user2@domain.com")
+
+        or
+
+        >>> obj.purge_from_cdn()
+
+        @param email: A Valid email address
+        @type email: str
+        """
+        if not self.container.conn.cdn_enabled:
+            raise CDNNotEnabled()
+
+        if email:
+            hdrs = {"X-Purge-Email": email}
+            response = self.container.conn.cdn_request('DELETE',
+                       [self.container.name, self.name], hdrs=hdrs)
+        else:
+            response = self.container.conn.cdn_request('DELETE',
+                       [self.container.name, self.name])
+
+        if (response.status < 200) or (response.status >= 299):
+            raise ResponseError(response.status, response.reason)
 
 
 class ObjectResults(object):
